@@ -5,9 +5,14 @@ import pytest
 
 import pyhomogenize as pyh
 
-from . import (has_dask, has_iteration_utilities, has_numpy, has_xarray,
-               requires_dask, requires_iteration_utilities, requires_numpy,
-               requires_xarray)
+from . import has_dask  # noqa
+from . import has_iteration_utilities  # noqa
+from . import has_numpy  # noqa
+from . import has_xarray  # noqa
+from . import requires_dask  # noqa
+from . import requires_iteration_utilities  # noqa
+from . import requires_numpy  # noqa
+from . import requires_xarray  # noqa
 
 netcdffile = [pyh.test_netcdf[1], pyh.test_netcdf[3]]
 time_control = pyh.time_control(netcdffile)
